#!/usr/bin/env bash

set -e

export CURDIR=$(pwd)

# EPEL has extra packages: https://fedoraproject.org/wiki/EPEL
yum install -y epel-release
yum -y update

yum install -y yum-utils wget bzip2 rpm-build redhat-rpm-config gcc gcc-c++ cmake3 extra-cmake-modules make openssl-devel \
               qt5-qtbase qt5-qtbase-devel qt5-qtwebkit-devel qtkeychain-qt5 qtkeychain-qt5-devel \
               qt5-qttools-devel qt5-qtbase-gui kf5-kio-devel  libsqlite3x-devel sqlite-devel desktop-file-utils kf5-kcoreaddons-devel \
               python-sphinx

cd /etc/yum.repos.d/
wget https://download.opensuse.org/repositories/isv:ownCloud:desktop/CentOS_7/isv:ownCloud:desktop.repo

yum-builddep -y owncloud-client

cd "${CURDIR}"

(
cat <<EOF
%_smp_mflags %( \
    [ -z "\$RPM_BUILD_NCPUS" ] \\\
        && RPM_BUILD_NCPUS="`/usr/bin/nproc 2>/dev/null || \\\
                             /usr/bin/getconf _NPROCESSORS_ONLN`"; \\\
    if [ "\$RPM_BUILD_NCPUS" -gt 16 ]; then \\\
        echo "-j16"; \\\
    elif [ "\$RPM_BUILD_NCPUS" -gt 3 ]; then \\\
        echo "-j\$RPM_BUILD_NCPUS"; \\\
    else \\\
        echo "-j3"; \\\
    fi )

%__arch_install_post \
    /usr/lib/rpm/check-buildroot
EOF
) > ${HOME}/.rpmmacros

echo "Rpmmacros:"

cat ${HOME}/.rpmmacros

mkdir -p rpmbuild/BUILD rpmbuild/RPMS rpmbuild/SOURCES rpmbuild/SPECS rpmbuild/SRPMS

echo "Preparing rpmbuild dir"

mv client stack-client
tar --exclude-vcs -cjf rpmbuild/SOURCES/stack-client.tar.bz2 stack-client

cp linux/centos/*.patch rpmbuild/SOURCES/
cp linux/centos/*.diff rpmbuild/SOURCES/
cp linux/centos/*.sh rpmbuild/SOURCES/
cp linux/centos/*.zip rpmbuild/SOURCES/
cp linux/centos/*.conf rpmbuild/SOURCES/
cp linux/centos/*.changes rpmbuild/SPECS/

cat linux/centos/stack-client.spec \
    | sed "s/\[\% shortname \%\]/stack/g" \
    | sed "s/\[\% create_msg \%\]/Version ${OWNCLOUD_VERSION}/g" \
    | sed "s/\[\% prerelease \%\]/%nil/g" \
    | sed "s/\[\% version \%\]/${OWNCLOUD_VERSION}/g" \
    | sed "s/\[\% tarball \%\]/stack-client/g" \
    | sed "s/\[\% APPLICATION_EXECUTABLE \%\]/stack/g" \
    | sed "s/\[\% pkgdescription \%\]/The STACK desktop sync client./g" \
    | sed "s/\[\% displayname \%\]/the STACK client/g" \
    | sed "s/\[\% buildjobid \%\]/${BUILDID}/g" \
    | sed 's|\[\% themedir \%\]|'$CURDIR'\/transiptheme|g' \
    | sed "s/\[\% shortname_etc \%\]/stack/g" \
    | sed "s/\[\% projecturl \%\]/https:\/\/github.com\/owncloud\/client/g" \
    > rpmbuild/SPECS/stack-client.spec

echo "The stack-client.spec file:"
cat rpmbuild/SPECS/stack-client.spec

echo "Theme dir:"
ls -al "${CURDIR}/transiptheme"

cd rpmbuild

echo "Starting Build: $(pwd)"

# Docker run command
rpmbuild -v -ba --define "_topdir ${CURDIR}/rpmbuild" --define="mirall_build_version ${OWNCLOUD_VERSION}" SPECS/stack-client.spec

cd RPMS/$(uname -m)

yum --disablerepo="*" --enablerepo="isv_ownCloud_desktop" list all | grep $(uname -m) | grep isv_ownCloud_desktop | grep -v cmake | awk '{ print $1 }' | grep -v owncloud | grep -v debuginfo | xargs -n1 yumdownloader -q -y --disablerepo="*" --enablerepo="isv_ownCloud_desktop"
