#!/usr/bin/env bash

if [ $CI_COMMIT_REF_NAME != "master" ]; then
    echo "Not on master, quitting"
    exit
fi

set -e

destdir=$1
signingkey=$2
distro=$3

export REPODIR=$(pwd)

cd $destdir

echo "Installing dependencies"
yum install -y createrepo unzip rpm-sign expect
echo "Importing signing key ${signingkey} and starting gpg-agent"
gpg --import "${signingkey}"
signingkeyId=$(gpg --list-secret-keys | grep 4096R | cut -d'/' -f2 | cut -d' ' -f1)
gpg --export -a "${signingkeyId}" > "RPM-GPG-KEY-${signingkeyId}"
rpm --import "RPM-GPG-KEY-${signingkeyId}"

echo "%_signature gpg" > ~/.rpmmacros
echo "%_gpg_name ${signingkeyId}" >> ~/.rpmmacros

echo "Signing all packages with key ${signingkeyId}"
for file in */*.rpm; do
	$REPODIR/linux/rpm-resign-cmd ${file}
done

echo "Creating repository information"
createrepo .

echo "Signing release."
echo ${REPOSITORY_KEY_PASSPHRASE} | gpg --detach-sign --passphrase-fd 0 --armor --batch --local-user "${signingkeyId}" repodata/repomd.xml

echo "Creating .repo file"
cat > transip-stack.repo <<EOL
[transip-stack]
name=TransIP Stack Client (${distro})
type=rpm-md
baseurl=http://mirror.transip.net/stack/software/yum/${distro}/
gpgcheck=1
gpgkey=http://mirror.transip.net/stack/release.key
enabled=1
EOL
